@@ -1,10 +1,11 @@
 /*
   Copyright (c) 2007 Till Adam <adam@kde.org>
-  Copyright (C) 2012-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2012-2019 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -87,7 +88,7 @@ public:
      * Imports filters. Ask the user where to import them from
      * and which filters to import.
      */
-    QList<MailFilter *> importFilters(
+    Q_REQUIRED_RESULT QList<MailFilter *> importFilters(
         bool &canceled, FilterImporterExporter::FilterType type = FilterImporterExporter::KMailFilter, const QString &filename = QString());
 
     /**
