@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -39,13 +39,13 @@ RedirectWidget::RedirectWidget(QWidget *parent)
 {
     QHBoxLayout *hbox = new QHBoxLayout(this);
     hbox->setSpacing(0);
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     hbox->setAlignment(Qt::AlignRight);
 
     mEdit = new MessageComposer::ComposerLineEdit(true);
     mEdit->setRecentAddressConfig(KernelIf->config().data());
     mEdit->setMinimumWidth(300);
-    mEdit->setClearButtonShown(true);
+    mEdit->setClearButtonEnabled(true);
     hbox->addWidget(mEdit);
 
     QPushButton *BtnTo = new QPushButton(this);
